@@ -4,5 +4,5 @@ __author__ = "Znunu"
 __version__ = "1.0.0"
 
 from .gbl import GB
-from .rewrite import *
+from .core import *
 from .args import parser
